from logging import LogRecord
from pprint import pprint
import elasticsearch_logging_handler
import logging_json
import logging.config


class Formatter(logging_json.JSONFormatter):

    def format(self, record: logging.LogRecord):
        record.line = f'{record.filename}:{record.lineno}'
        return super().format(record)


class Handler(elasticsearch_logging_handler.ElasticHandler):

    def emit(self, record: LogRecord) -> None:
        super().emit(record)


logging.config.dictConfig({
    "version": 1,
    "formatters": {
        "json": {
            '()': Formatter,
            'style': "{",
            'fields': {
                "level_name": "levelname",
                "thread_name": "threadName",
                "process_name": "processName",
                "line": "line",
            },
        }
    },
    "handlers": {
        "standard_output": {
            'class': 'logging.StreamHandler',
            'formatter': 'json',
            'stream': 'ext://sys.stdout',
            'level': 'DEBUG',
        },
    },
    "root": {
        "level": "DEBUG",
        "handlers": ["standard_output"]
    }
})
logging.basicConfig(level=logging.DEBUG)
log = logging.getLogger()

h = Handler(host="http://10.43.219.126:80/logs/insert/elasticsearch/",
            index='unused',
            level=logging.DEBUG,
            timezone='America/Los_Angeles')
log.addHandler(h)
